"""
    .. include:: ../ulmo/cuahsi/wof/README.rst
"""
from __future__ import absolute_import

from . import core

from .core import get_sites, get_site_info, get_values, get_variable_info
